%% (Stable) Step Response Features

% Step response
t=linspace(0,15,100);
G = tf(2,[1 0.6 1]);
[y,t]=step(G,t);

% Plot response
figure(1);
clf;
plot(t,y);
hold on
xlabel('Time (sec)')

% Final value
ybar = dcgain(G);
plot([0 t(end)],ybar*[1 1],'r:')

% 5 percent Settling Time
idx = max( find((y>1.05*ybar | y<0.95*ybar)) );
Ts = t(idx);
plot([Ts t(end)],0.95*ybar*[1 1],'k--');
plot([Ts t(end)],1.05*ybar*[1 1],'k--');
plot(Ts*[1 1],[0 0.95*ybar],'k--');

% Rise Time
idx = min( find(y>ybar) );
Tr = t(idx);
plot(Tr*[1 1],[0 ybar],'k--');

% Peak Time
[ypeak,idx] = max(y);
Tp = t(idx);
plot(Tp*[1 1],[0 ypeak],'k--');

% Create labels
set(gca,'Xtick',[Tr Tp Ts],'XtickLabel',{'Tr'; 'Tp'; 'Ts'});
set(gca,'Ytick',[ybar ypeak],'YtickLabel',{'ybar'; 'y(Tp)'});

if exist('garyfyFigure','file') && exist('matlab2tikz','file');
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    % savefig('StepFeatures',1,'pdf')    
    set(gca,'Xtick',[Tr Tp Ts],'XtickLabel',{'$T_r$'; '$T_p$'; '$T_s$'});
    set(gca,'Ytick',[ybar ypeak],'YtickLabel',{'$\bar{y}$'; '$y(T_p)$'});
    matlab2tikz('StepFeatures.tikz','width','\figurewidth');
end
