%% Underdamped Roots
% Definition of natural frequency, damping ratio, and damped natural
% frequency for underdamped (complex) roots.

%% Define complex root
s = -6+4j;

%% Quantities Associated with Complex Root

% Real / Imaginary Parts
re = real(s);
im = imag(s);

% Natural frequency, damping ratio, damped natural frequency
wn = abs(s);
wd = im;
zeta = -re/wn;

% Time constant
tau = 1/abs(re);

%% DAMP
% The damp function (with no outputs) displays most of these quantities. 
% Alternatively the function can return wn and zeta:
%    [wn,zeta] = damp(s);
damp(s)

%% Plot 

% Plot Roots
figure(1)
clf;
plot(re,im,'rx',re,-im,'rx','MarkerSize',14);
hold on;
xlabel('Real');
ylabel('Imag');

% Lines for axes and from origin to roots
ax=[-8.8 3.8 -5 5];
axis(ax);
ph(1)=plot(0.97*[0 re],0.97*[0,im],'k:');
ph(2)=plot(0.97*[0 re],0.97*[0,-im],'k:');
ph(3)=plot([0 0],ax(3:4),'k');
ph(4)=plot(ax(1:2),[0 0],'k');

% Text Labels
th(1) = text(0.55*re,0.6*im,'\omega_n','FontSize',18);

ph(5)=plot([re re],0.25*[-1 1],'k');
th(2) = text(re,-0.75,'-\zeta \omega_n','FontSize',18,...
    'HorizontalAlignment','Center');

ph(6)=plot(0.2*[-1 1],[im im],'k');
ph(7)=plot(0.2*[-1 1],[-im -im],'k');
th(3) = text(0.1,0.96*im,'\omega_d','FontSize',18);
th(4) = text(0.1,-1.04*im,'-\omega_d','FontSize',18);

theta = linspace(0.05,asin(zeta)-0.05,25);
ph(8)= plot(-1.25*sin(theta),1.25*cos(theta),'k');
th(5) = text(-1.2,1.7,'\theta','FontSize',18);

%axis equal
set(gca,'Xtick',[],'Ytick',[]);
hold off;

if exist('garyfyFigure','file') && exist('matlab2tikz','file');
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set(ph,'LineWidth',1.5)
    for i=1:numel(th)
        set(th(i),'String',['$' get(th(i),'String') '$']);
    end
    
    warning('Not Saving File')
    % To add arrowheads: \addplot[<->,...   
%     matlab2tikz('UnderdampedRoots.tikz','width','\figurewidth',...
%         'parseStrings',false,'extraAxisOptions',...
%         'ylabel near ticks, xlabel near ticks');
end
